==> vtigercrm-5.2.1.tgz: modules/HelpDesk/language/de_de.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header$
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * Description:  Defines the German language pack for the base application.
 * All Rights Reserved.
 * Contributor(s): 4net AG, Schoretshuebstr. 26 , CH-9015 St.Gallen
 *                  crm-now, Berlin, www.crm-now.com
 ********************************************************************************/
$mod_strings = Array(
// Added in release 4.0
'LBL_MODULE_NAME'=>'Trouble Tickets',
'LBL_GROUP'=>'Gruppe',
'LBL_ACCOUNT_NAME'=>'Organisation',
'LBL_CONTACT_NAME'=>'Person',
'LBL_SUBJECT'=>'Betreff',
'LBL_NEW_FORM_TITLE' => 'Neues Ticket',
'LBL_DESCRIPTION'=>'Beschreibung',
'NTC_DELETE_CONFIRMATION'=>'Möchten Sie diesen Eintrag löschen?',
'LBL_CUSTOM_FIELD_SETTINGS'=>'Einstellungen Benutzerfelder:',
'LBL_PICKLIST_FIELD_SETTINGS'=>'Einstellungen Auswahllisten:',
'Leads'=>'Lead',
'Accounts'=>'Organisationen',
'Contacts'=>'Personen',
'Opportunities'=>'Verkaufspotentiale',
'LBL_CUSTOM_INFORMATION'=>'zusätzliche Information',
'LBL_DESCRIPTION_INFORMATION'=>'Beschreibung',

'LBL_ACCOUNT'=>'Organisation',
'LBL_OPPURTUNITY'=>'Verkaufspotential',
'LBL_PRODUCT'=>'Produkt',

'LBL_COLON'=>':',
'LBL_TICKET'=>'Ticket',
'LBL_CONTACT'=>'Person',
'LBL_STATUS'=>'Status',
'LBL_ASSIGNED_TO'=>'zuständig ',
'LBL_FAQ'=>'Wissensbasis',
'LBL_VIEW_FAQS'=>'zeige Themen',
'LBL_ADD_FAQS'=>'erstelle Themen',
'LBL_FAQ_CATEGORIES'=>'Themen Kategorien',

'LBL_PRIORITY'=>'Priorität',
'LBL_CATEGORY'=>'Kategorie',

'LBL_ANSWER'=>'Antwort',
'LBL_COMMENTS'=>'Kommentar',

'LBL_AUTHOR'=>'Autor',
'LBL_QUESTION'=>'Frage',

//Added fields for File Attachment and Mail send in Tickets
'LBL_ATTACHMENTS'=>'Anhang',
'LBL_NEW_ATTACHMENT'=>'Neuer Anhang',
'LBL_SEND_MAIL'=>'sende E-Mail',

//Added fields for search option  in TicketsList -- 4Beta
'LBL_CREATED_DATE'=>'Erstelldatum',
'LBL_IS'=>'ist',
'LBL_IS_NOT'=>'ist nicht',
'LBL_IS_BEFORE'=>'ist vor',
'LBL_IS_AFTER'=>'ist nach',
'LBL_STATISTICS'=>'Statistik',
'LBL_TICKET_ID'=>'Ticketnummer',
'LBL_MY_TICKETS'=>'Meine Tickets',
"LBL_MY_FAQ"=>"Meine Themen",
'LBL_ESTIMATED_FINISHING_TIME'=>'erwartete Fertigstellung',
'LBL_SELECT_TICKET'=>'Ticket wählen',
'LBL_CHANGE_OWNER'=>'Besitzer wechseln',
'LBL_CHANGE_STATUS'=>'Status wechseln',
'LBL_TICKET_TITLE'=>'Titel',
'LBL_TICKET_DESCRIPTION'=>'Beschreibung',
'LBL_TICKET_CATEGORY'=>'Kategorie',
'LBL_TICKET_PRIORITY'=>'Priorität',

//Added fields after 4 -- Beta
'LBL_NEW_TICKET'=>'Neues Ticket',
'LBL_TICKET_INFORMATION'=>'Ticket',

'LBL_LIST_FORM_TITLE'=>'Tickets',
'LBL_SEARCH_FORM_TITLE'=>'Ticket suchen',

//Added fields after RC1 - Release
'LBL_CHOOSE_A_VIEW'=>'Ansicht auswählen...',
'LBL_ALL'=>'Alle',
'LBL_LOW'=>'gering',
'LBL_MEDIUM'=>'mittel',
'LBL_HIGH'=>'hoch',
'LBL_CRITICAL'=>'kritisch',
//Added fields for 4GA
'Assigned To'=>'zuständig',
'Contact Name'=>'Person',
'Priority'=>'Priorität',
'Status'=>'Status',
'Category'=>'Kategorie',
'Update History'=>'Verlauf aktualisieren',
'Created Time'=>'erstellt',
'Modified Time'=>'geändert',
'Title'=>'Titel',
'Description'=>'Beschreibung',

'LBL_TICKET_CUMULATIVE_STATISTICS'=>'Ticket-Statistik:',
'LBL_CASE_TOPIC'=>'Vorfall',
'LBL_OPEN'=>'offen',
'LBL_CLOSED'=>'geschlossen',
'LBL_TOTAL'=>'Total',
'LBL_TICKET_HISTORY'=>'Ticketverlauf:',
'LBL_CATEGORIES'=>'Kategorien',
'LBL_PRIORITIES'=>'Prioritäten',
'LBL_SUPPORTERS'=>'Supporter',

//Added fields after 4_0_1
'LBL_TICKET_RESOLUTION'=>'Lösung',
'Solution'=>'Lösung',
'Add Comment'=>'Kommentar hinzufügen',
'LBL_ADD_COMMENT'=>'Kommentar hinzufügen',//give the same value given to the above string 'Add Comment'

//Added for 4.2 Release -- CustomView
'Ticket ID'=>'Ticketnummer',
'Subject'=>'Thema',

//Added after 4.2 alpha
'Severity'=>'Gewichtung',
'Product Name'=>'Produktname',
'Related To'=>'bezogen auf',
'LBL_MORE'=>'mehr',

'LBL_TICKETS'=>'Tickets',

//Added on 09-12-2005
'LBL_CUMULATIVE_STATISTICS'=>'Zusammenfassende Statistik',

//Added on 12-12-2005
'LBL_CONVERT_AS_FAQ_BUTTON_TITLE'=>'zur Wissensbasis hinzufügen',
'LBL_CONVERT_AS_FAQ_BUTTON_KEY'=>'C',
'LBL_CONVERT_AS_FAQ_BUTTON_LABEL'=>'zur Wissensbasis hinzufügen',
'Attachment'=>'Anhang',
'LBL_COMMENT_INFORMATION'=>'Kommentare',

//Added for existing picklist entries

'Big Problem'=>'grosses Problem',
'Small Problem'=>'kleines Problem',
'Other Problem'=>'anderes Problem',

'Low'=>'gering',
'Normal'=>'normal',
'High'=>'hoch',
'Urgent'=>'dringend',

'Minor'=>'gering',
'Major'=>'bedeutend',
'Feature'=>'Eigenschaft',
'Critical'=>'kritisch',

'Open'=>'offen',
'In Progress'=>'in Bearbeitung',
'Wait For Response'=>'warte auf Zuarbeit',
'Closed'=>'geschlossen',

//added to support i18n in ticket mails
'Hi' => 'Hallo',
'Dear'=> 'Hallo',
'LBL_PORTAL_BODY_MAILINFO'=> 'Ein Ticket wurde',
'LBL_DETAIL' => 'Hier sind die Details dazu :',
'LBL_REGARDS'=> 'Danke',
'LBL_TEAM'=> 'HelpDesk Team',
'LBL_TICKET_DETAILS' => 'Ticket Details',
'LBL_SUBJECT' => 'Betreff : ',
'created' => 'erzeugt.',
'replied' => 'beantwortet.',
'reply'=>'Es gibt eine Antwort zu Ihrem Anliegen ',
'customer_portal' => ' im Kundenportal des CRM Systems.',
'link' => ' Loggen Sie sich in das Kundenportal ein und nutzen Sie den folgenden Link, um die Nachricht zu sehen:',
'Thanks' => 'Danke',
'Support_team' => 'Support Team',

// Added/Updated for vtiger CRM 5.0.4

//this label for customerportal.
'LBL_STATUS_CLOSED' =>'Closed',//Do not convert this label. This is used to check the status. If the status 'Closed' is changed in vtigerCRM server side then you have to change in customerportal language file also.
'LBL_STATUS_UPDATE' => 'Neuer Ticket Status: ',
'LBL_COULDNOT_CLOSED' => 'Der nachfolgende Ticket Status konnte nicht gesetzt werden:',
'LBL_CUSTOMER_COMMENTS' => 'Der Kunde hat die folgenden zusätzlichen Infomationen zu dem Ticket hinzugefügt:',
'LBL_RESPOND'=> 'Bitte kümmern Sie sich darum.',
'LBL_REGARDS' =>'Mit freundlichen Grüßen,',
'LBL_SUPPORT_ADMIN' => 'Support Administrator',
'LBL_RESPONDTO_TICKETID' =>'Antwort zum Ticket Nr.',
'LBL_CUSTOMER_PORTAL' => ' im Kundenportal - Dringend!', 
'LBL_LOGIN_DETAILS' => 'Hier sind Ihre Login Daten für das Kundenportal: ',
'LBL_MAIL_COULDNOT_SENT' =>'Die E-Mail konnte nicht gesendet werden.',
'LBL_USERNAME' => 'Benutzername: ',
'LBL_PASSWORD' => 'Passwort: ',
'LBL_SUBJECT_PORTAL_LOGIN_DETAILS' => 'Ihnen wurde der Zugang zum Kundenportal freigeschaltet',
'LBL_GIVE_MAILID' => 'Bitte die E-Mail Adresse angeben',
'LBL_CHECK_MAILID' => 'Bitte korrigieren Sie Ihre E-Mail Adresse',
'LBL_LOGIN_REVOKED' => 'Sie haben keine Zugangsberechtigung mehr. Bitte kontaktieren Sie den Administrator.',
'LBL_MAIL_SENT' => 'Eine E-Mail mit den Zugangsdaten wurde zu Ihnen gesendet.',
'LBL_ALTBODY' => 'Das ist die Nachricht für Clients ohne HTML',

// Added after 5.0.4 GA

// Module Sequence Numbering
'Ticket No' => 'interne Ticket Nr.',
// END

'Hours' => 'Stunden',
'Days' => 'Tage',
);

?>

==> vtigercrm-5.3.0p0.tgz: modules/HelpDesk/language/de_de.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
$mod_strings = Array(
// Added in release 4.0
'LBL_MODULE_NAME'=>'Trouble Tickets',
'LBL_GROUP'=>'Gruppe',
'LBL_ACCOUNT_NAME'=>'Organisation',
'LBL_CONTACT_NAME'=>'Person',
'LBL_SUBJECT'=>'Betreff',
'LBL_NEW_FORM_TITLE' => 'Neues Ticket',
'LBL_DESCRIPTION'=>'Beschreibung',
'NTC_DELETE_CONFIRMATION'=>'Möchten Sie diesen Eintrag löschen?',
'LBL_CUSTOM_FIELD_SETTINGS'=>'Einstellungen Benutzerfelder:',
'LBL_PICKLIST_FIELD_SETTINGS'=>'Einstellungen Auswahllisten:',
'Leads'=>'Lead',
'Accounts'=>'Organisationen',
'Contacts'=>'Personen',
'Opportunities'=>'Verkaufspotentiale',
'LBL_CUSTOM_INFORMATION'=>'zusätzliche Information',
'LBL_DESCRIPTION_INFORMATION'=>'Beschreibung',

'LBL_ACCOUNT'=>'Organisation',
'LBL_OPPURTUNITY'=>'Verkaufspotential',
'LBL_PRODUCT'=>'Produkt',

'LBL_COLON'=>':',
'LBL_TICKET'=>'Ticket',
'LBL_CONTACT'=>'Person',
'LBL_STATUS'=>'Status',
'LBL_ASSIGNED_TO'=>'zuständig ',
'LBL_FAQ'=>'Wissensbasis',
'LBL_VIEW_FAQS'=>'zeige Themen',
'LBL_ADD_FAQS'=>'erstelle Themen',
'LBL_FAQ_CATEGORIES'=>'Themen Kategorien',

'LBL_PRIORITY'=>'Priorität',
'LBL_CATEGORY'=>'Kategorie',

'LBL_ANSWER'=>'Antwort',
'LBL_COMMENTS'=>'Kommentar',

'LBL_AUTHOR'=>'Autor',
'LBL_QUESTION'=>'Frage',

//Added fields for File Attachment and Mail send in Tickets
'LBL_ATTACHMENTS'=>'Anhang',
'LBL_NEW_ATTACHMENT'=>'Neuer Anhang',
'LBL_SEND_MAIL'=>'sende E-Mail',

//Added fields for search option  in TicketsList -- 4Beta
'LBL_CREATED_DATE'=>'Erstelldatum',
'LBL_IS'=>'ist',
'LBL_IS_NOT'=>'ist nicht',
'LBL_IS_BEFORE'=>'ist vor',
'LBL_IS_AFTER'=>'ist nach',
'LBL_STATISTICS'=>'Statistik',
'LBL_TICKET_ID'=>'Ticketnummer',
'LBL_MY_TICKETS'=>'Meine Tickets',
"LBL_MY_FAQ"=>"Meine Themen",
'LBL_ESTIMATED_FINISHING_TIME'=>'erwartete Fertigstellung',
'LBL_SELECT_TICKET'=>'Ticket wählen',
'LBL_CHANGE_OWNER'=>'Besitzer wechseln',
'LBL_CHANGE_STATUS'=>'Status wechseln',
'LBL_TICKET_TITLE'=>'Titel',
'LBL_TICKET_DESCRIPTION'=>'Beschreibung',
'LBL_TICKET_CATEGORY'=>'Kategorie',
'LBL_TICKET_PRIORITY'=>'Priorität',

//Added fields after 4 -- Beta
'LBL_NEW_TICKET'=>'Neues Ticket',
'LBL_TICKET_INFORMATION'=>'Ticket',

'LBL_LIST_FORM_TITLE'=>'Tickets',
'LBL_SEARCH_FORM_TITLE'=>'Ticket suchen',

//Added fields after RC1 - Release
'LBL_CHOOSE_A_VIEW'=>'Ansicht auswählen...',
'LBL_ALL'=>'Alle',
'LBL_LOW'=>'gering',
'LBL_MEDIUM'=>'mittel',
'LBL_HIGH'=>'hoch',
'LBL_CRITICAL'=>'kritisch',
//Added fields for 4GA
'Assigned To'=>'zuständig',
'Contact Name'=>'Person',
'Priority'=>'Priorität',
'Status'=>'Status',
'Category'=>'Kategorie',
'Update History'=>'Verlauf aktualisieren',
'Created Time'=>'erstellt',
'Modified Time'=>'geändert',
'Title'=>'Titel',
'Description'=>'Beschreibung',

'LBL_TICKET_CUMULATIVE_STATISTICS'=>'Ticket-Statistik:',
'LBL_CASE_TOPIC'=>'Vorfall',
'LBL_OPEN'=>'offen',
'LBL_CLOSED'=>'geschlossen',
'LBL_TOTAL'=>'Total',
'LBL_TICKET_HISTORY'=>'Ticketverlauf:',
'LBL_CATEGORIES'=>'Kategorien',
'LBL_PRIORITIES'=>'Prioritäten',
'LBL_SUPPORTERS'=>'Supporter',

//Added fields after 4_0_1
'LBL_TICKET_RESOLUTION'=>'Lösung',
'Solution'=>'Lösung',
'Add Comment'=>'Kommentar hinzufügen',
'LBL_ADD_COMMENT'=>'Kommentar hinzufügen',//give the same value given to the above string 'Add Comment'

//Added for 4.2 Release -- CustomView
'Ticket ID'=>'Ticketnummer',
'Subject'=>'Thema',

//Added after 4.2 alpha
'Severity'=>'Gewichtung',
'Product Name'=>'Produktname',
'Related To'=>'bezogen auf',
'LBL_MORE'=>'mehr',

'LBL_TICKETS'=>'Tickets',

//Added on 09-12-2005
'LBL_CUMULATIVE_STATISTICS'=>'Zusammenfassende Statistik',

//Added on 12-12-2005
'LBL_CONVERT_AS_FAQ_BUTTON_TITLE'=>'zur Wissensbasis hinzufügen',
'LBL_CONVERT_AS_FAQ_BUTTON_KEY'=>'C',
'LBL_CONVERT_AS_FAQ_BUTTON_LABEL'=>'zur Wissensbasis hinzufügen',
'Attachment'=>'Anhang',
'LBL_COMMENT_INFORMATION'=>'Kommentare',

//Added for existing picklist entries

'Big Problem'=>'grosses Problem',
'Small Problem'=>'kleines Problem',
'Other Problem'=>'anderes Problem',

'Low'=>'gering',
'Normal'=>'normal',
'High'=>'hoch',
'Urgent'=>'dringend',

'Minor'=>'gering',
'Major'=>'bedeutend',
'Feature'=>'Eigenschaft',
'Critical'=>'kritisch',

'Open'=>'offen',
'In Progress'=>'in Bearbeitung',
'Wait For Response'=>'warte auf Zuarbeit',
'Closed'=>'geschlossen',

//added to support i18n in ticket mails
'Hi' => 'Hallo',
'Dear'=> 'Hallo',
'LBL_PORTAL_BODY_MAILINFO'=> 'Ein Ticket wurde',
'LBL_DETAIL' => 'Hier sind die Details dazu :',
'LBL_REGARDS'=> 'Danke',
'LBL_TEAM'=> 'HelpDesk Team',
'LBL_TICKET_DETAILS' => 'Ticket Details',
'LBL_SUBJECT' => 'Betreff : ',
'created' => 'erzeugt.',
'replied' => 'beantwortet.',
'reply'=>'Es gibt eine Antwort zu Ihrem Anliegen ',
'customer_portal' => ' im Kundenportal des CRM Systems.',
'link' => ' Loggen Sie sich in das Kundenportal ein und nutzen Sie den folgenden Link, um die Nachricht zu sehen:',
'Thanks' => 'Danke',
'Support_team' => 'Support Team',

// Added/Updated for vtiger CRM 5.0.4

//this label for customerportal.
'LBL_STATUS_CLOSED' =>'Closed',//Do not convert this label. This is used to check the status. If the status 'Closed' is changed in vtigerCRM server side then you have to change in customerportal language file also.
'LBL_STATUS_UPDATE' => 'Neuer Ticket Status: ',
'LBL_COULDNOT_CLOSED' => 'Der nachfolgende Ticket Status konnte nicht gesetzt werden:',
'LBL_CUSTOMER_COMMENTS' => 'Der Kunde hat die folgenden zusätzlichen Infomationen zu dem Ticket hinzugefügt:',
'LBL_RESPOND'=> 'Bitte kümmern Sie sich darum.',
'LBL_REGARDS' =>'Mit freundlichen Grüßen,',
'LBL_SUPPORT_ADMIN' => 'Support Administrator',
'LBL_RESPONDTO_TICKETID' =>'Antwort zum Ticket Nr.',
'LBL_CUSTOMER_PORTAL' => ' im Kundenportal - Dringend!', 
'LBL_LOGIN_DETAILS' => 'Hier sind Ihre Login Daten für das Kundenportal: ',
'LBL_MAIL_COULDNOT_SENT' =>'Die E-Mail konnte nicht gesendet werden.',
'LBL_USERNAME' => 'Benutzername: ',
'LBL_PASSWORD' => 'Passwort: ',
'LBL_SUBJECT_PORTAL_LOGIN_DETAILS' => 'Ihnen wurde der Zugang zum Kundenportal freigeschaltet',
'LBL_GIVE_MAILID' => 'Bitte die E-Mail Adresse angeben',
'LBL_CHECK_MAILID' => 'Bitte korrigieren Sie Ihre E-Mail Adresse',
'LBL_LOGIN_REVOKED' => 'Sie haben keine Zugangsberechtigung mehr. Bitte kontaktieren Sie den Administrator.',
'LBL_MAIL_SENT' => 'Eine E-Mail mit den Zugangsdaten wurde zu Ihnen gesendet.',
'LBL_ALTBODY' => 'Das ist die Nachricht für Clients ohne HTML',

// Added after 5.0.4 GA

// Module Sequence Numbering
'Ticket No' => 'interne Ticket Nr.',
// END

'Hours' => 'Stunden',
'Days' => 'Tage',

'The comments are' => 'Die Kommentare sind',
'Ticket Title' => 'Ticket Titel',
'Re' => 'Re :',
);

?>
